==> ingdao-0.0.1.tar.gz: lib/dataflow/control/dfqueryentityjoin.dart <==
import 'package:meta/meta.dart';
import '../entity/dfbaseentity.dart';
import '../entity/dfdbentity.dart';

enum JoinType {
  leftJoin,
  innerJoin,
  rightJoin
}

extension JoinTypeExtension on JoinType {

  String get name {
    switch (this) {
      case JoinType.leftJoin:
        return 'LEFT JOIN';
      case JoinType.innerJoin:
        return 'INNER JOIN';
     case JoinType.rightJoin:
        return 'RIGHT JOIN';        
      default:
        return null;
    }
  }

  String desp() {
    return this.name;
  }
}

class DfQueryEntityJoin {
  List<DfBaseEntity> entities;
  List<JoinType> joins;

  DfQueryEntityJoin({@required this.entities, this.joins});

  String toSource() {
    if (entities.length == 1) {
      return entities[0].name;
    }
    else if (entities.length == 0) {
      return '';
    }
    else {
      String result = "";
      int joinIdx = 0;
      for (int i = 0; i < entities.length; i += 2) {
        if (i >= entities.length - 1) {
          break;
        }
        if (result.length > 0) {
          result = "$result ";
        }
        String leftEntity = entities[i].name;
        String rightEntity = entities[i + 1].name;
        JoinType join = joins[joinIdx++];
        String joinName = join.name;
        String joinCri = formJoinCri(entities[i],entities[i+1]);

        result = "$result$leftEntity $joinName $rightEntity on $joinCri";
      }
      return result;
    }    
  }

  String formJoinCri(DfBaseEntity leftEntity, DfBaseEntity rightEntity) {
    String result = "";
    DfDbEntity leftEnt = leftEntity;
    DfDbEntity rightEnt = rightEntity;
    var leftEntityJoinFields = leftEnt.getJoinKeyFields();
    var rightEntityJoinFields = rightEnt.getJoinKeyFields();

    for (int i = 0; i < leftEntityJoinFields.length; i++) {
      if (result.length > 0) {
        result = ("$result AND ");
      }
      String leftEntityJoinField = leftEntity.name + "." + leftEntityJoinFields[i].name;
      String rightEntityJoinField = rightEntity.name + "." + rightEntityJoinFields[i].name;
      result = "$result$leftEntityJoinField = $rightEntityJoinField";
    }

    return result;    
  }
}

==> ingdao-0.0.19.tar.gz: lib/dataflow/control/dfqueryentityjoin.dart <==
import 'package:meta/meta.dart';
import '../entity/dfbaseentity.dart';
import '../entity/dfdbentity.dart';

enum JoinType {
  leftJoin,
  innerJoin,
  rightJoin
}

extension JoinTypeExtension on JoinType {

  String get name {
    switch (this) {
      case JoinType.leftJoin:
        return 'LEFT JOIN';
      case JoinType.innerJoin:
        return 'INNER JOIN';
     case JoinType.rightJoin:
        return 'RIGHT JOIN';        
      default:
        return null;
    }
  }

  String desp() {
    return this.name;
  }
}

class DfQueryEntityJoin {
  List<DfBaseEntity> entities;
  List<JoinType> joins;

  DfQueryEntityJoin({@required this.entities, this.joins});

  String toSource() {
    if (entities.length == 1) {
      return entities[0].entityName;
    }
    else if (entities.length == 0) {
      return '';
    }
    else {
      String result = "";
      int joinIdx = 0;
      for (int i = 0; i < entities.length; i += 2) {
        if (i >= entities.length - 1) {
          break;
        }
        if (result.length > 0) {
          result = "$result ";
        }
        String leftEntity = entities[i].entityName;
        String rightEntity = entities[i + 1].entityName;
        JoinType join = joins[joinIdx++];
        String joinName = join.name;
        String joinCri = formJoinCri(entities[i],entities[i+1]);

        result = "$result$leftEntity $joinName $rightEntity on $joinCri";
      }
      return result;
    }    
  }

  String formJoinCri(DfBaseEntity leftEntity, DfBaseEntity rightEntity) {
    String result = "";
    DfDbEntity leftEnt = leftEntity;
    DfDbEntity rightEnt = rightEntity;
    var leftEntityJoinFields = leftEnt.getJoinKeyFields();
    var rightEntityJoinFields = rightEnt.getJoinKeyFields();

    for (int i = 0; i < leftEntityJoinFields.length; i++) {
      if (result.length > 0) {
        result = ("$result AND ");
      }
      String leftEntityJoinField = leftEntity.entityName + "." + leftEntityJoinFields[i].name;
      String rightEntityJoinField = rightEntity.entityName + "." + rightEntityJoinFields[i].name;
      result = "$result$leftEntityJoinField = $rightEntityJoinField";
    }

    return result;    
  }
}
